﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Drawing;
using System.Data;
using System.Linq;
using System.Text;
using System.Windows.Forms;
using C1.Win.C1FlexGrid;
using C1.Win.C1Command;
using System.IO;

namespace Sample_DragExcelInFlex
{
    public partial class FlexUC : UserControl
    {
        //File Name that stores the file being dragged or opened
        string file;
        //List of alphabets for Flexgrid columns
        List<string> result = new List<string>();

        public FlexUC()
        {
            InitializeComponent();
            createList();
            UpdateFields();
        }

        #region ***Methods
        //Method to set the Row and Column names
        private void SetRowColNames()
        {
            for (int r = 0; r < _flex.Rows.Count; r++)
                _flex[r, 0] = r;

            for (int c = 0; c < _flex.Cols.Count; c++)
            {
                if (c == 0)
                    continue;
                else
                    _flex[0, c] = result[c - 1];
            }
            _flex[0, 0] = "";
        }
       
        //Method to create a list of alphabets for the Flexgrid columns
        private void createList()
        {
            for (char ch = 'A'; ch <= 'Z'; ch++)
            {
                result.Add(ch.ToString());
            }

            for (char i = 'A'; i <= 'Z'; i++)
            {
                for (char j = 'A'; j <= 'Z'; j++)
                {
                    result.Add(i.ToString() + j.ToString());
                }
            }
        }
        
        //Load Excel File in C1Flexgrid
        private void LoadExcelInFlex()
        {
            if ((file.EndsWith(".xls")) || (file.EndsWith(".xlsx")))
            {
                _flex.DataSource = null;
                _flex.LoadExcel(file);
                AddTabs();
                UpdateFields();
            }
            else
            {
                MessageBox.Show("Please select an Excel file");
            }
        }

        //Add Sheet tabs 
        private void AddTabs()
        {
            _sheetTabs.TabPages.Clear();
            string[] sheetnames = _flex.LoadExcelSheetNames(file);
            foreach (string str in sheetnames)
            {
                C1DockingTabPage dtpage = new C1DockingTabPage();
                dtpage.Name = str;
                dtpage.Text = str;
                _sheetTabs.TabPages.Add(dtpage);
            }
            _sheetTabs.SelectedIndex = 0;
        }

        //Method to update the fields in the UI
        private void UpdateFields()
        {
            SetRowColNames();
            int selcol = _flex.Col;
            int selrow = _flex.Row;
            label1.Text = _flex.GetDataDisplay(0, selcol) + selrow.ToString();

            try { textBox1.Text = _flex.GetDataDisplay(selrow, selcol); }
            catch(Exception ex) { System.Diagnostics.Debug.WriteLine(ex.Message);}
           
        }

        #endregion

        #region ***Events
        //Handles DragEnter Event
        private void _flex_DragEnter(object sender, DragEventArgs e)
        {
            if (e.Data.GetDataPresent(DataFormats.FileDrop, false) == true)
                e.Effect = DragDropEffects.Move;
            else
                e.Effect = DragDropEffects.None;
        }
        
        //Loads the dragged excel file
        private void _flex_DragDrop(object sender, DragEventArgs e)
        {
            file = string.Empty;

            string[] str = (string[])e.Data.GetData(DataFormats.FileDrop);

            foreach (string s in str)
                file += s;
            LoadExcelInFlex();
        }

        //Displays the value of the selected cell in the textbox
        private void _flex_SelChange(object sender, EventArgs e)
        {
            int selcol = _flex.Col;
            int selrow = _flex.Row;
            label1.Text = _flex.GetDataDisplay(0, selcol) + selrow.ToString();

            try { textBox1.Text = _flex.GetDataDisplay(selrow, selcol); }
            catch (Exception ex) { System.Diagnostics.Debug.WriteLine(ex.Message); }
           
        }

        //Loads the selected sheet
        private void _sheetTabs_SelectedIndexChanged(object sender, EventArgs e)
        {
            if (_sheetTabs.TabPages.Count > 0)
            {
                string sheetname = _sheetTabs.SelectedTab.Text;
                _flex.LoadExcel(file, sheetname);
                UpdateFields();
            }
        }
        #endregion

        #region ***Menu Events
        
        //Open a Excel file
        private void c1Command1_Click(object sender, ClickEventArgs e)
        {
            OpenFileDialog odialog = new OpenFileDialog();
            odialog.Title = "Select Excel File to load in C1FlexGrid";

            odialog.Filter = "Excel Workbook 2003(*.xls)|*.xls|Excel Workbook 2007(*.xlsx)|*.xlsx";

            if (odialog.ShowDialog() == DialogResult.OK)
            {
                file = odialog.FileName;
                _flex.LoadExcel(file);
                AddTabs();
                UpdateFields();
            }
        }
        //Saves Excel File
        private void c1Command2_Click(object sender, ClickEventArgs e)
        {
            SaveFileDialog saveFileDialog1 = new SaveFileDialog();
            saveFileDialog1.Filter = "Excel Workbook 2003(*.xls)|*.xls|Excel Workbook 2007(*.xlsx)|*.xlsx";
            saveFileDialog1.Title = "Save an Excel File";
            saveFileDialog1.ShowDialog();

            // If the file name is not an empty string open it for saving.
            if (saveFileDialog1.FileName != "")
               _flex.SaveExcel(saveFileDialog1.FileName, FileFlags.AsDisplayed);
        }
        //Exit Application
        private void c1Command3_Click(object sender, ClickEventArgs e)
        {
            Application.Exit();
        }
        #endregion
    }
}

